### A sample scenario that demonstrate ArgoCD Interlacer's capability 

This example scenario will walk you through 

- Creating an application resource in ArgoCD
- Verifying signature and retriving manifest generated by ArgoCD Interlace
- Verifying provenance generated by ArgoCD Interlace

## Creating an application resource in ArgoCD

To create [a sample ArgoCD application](https://github.com/kubernetes-sigs/kustomize/tree/master/examples/helloWorld), run:
```shell
kubectl apply --filename https://raw.githubusercontent.com/IBM/argocd-interlace/main/examples/application.yaml
```
ArgoCD will deploy this application to `helloworld-ns` namespace.

## Verifying signature and retriving manifest generated by ArgoCD Interlace

ArgoCD Interlace generates signed manifest as an OCI image and push it to an image registry.

Example OCI image name will look like:  `gcr.io/some-image-registry/<image-prefix>-app-helloworld:mnf`

To fetch the manifest by digest using the OCI URL and verify its signature automatically, install [cosign](https://github.com/sigstore/cosign) and run the following:

```shell
sget -o tmp/artifact.tar.gz -key cosign-keys/cosign.pub gcr.io/some-image-registry/<image-prefix>-app-helloworld:mnf
```

Successful verification will show an output like below. The signature of the OCI image is verified automatically by sget as part of the download of manifest (stored at `tmp/artifact.tar.gz`).

```
Verification for gcr.io/some-image-registry/<image-prefix>-app-helloworld:mnf --
The following checks were performed on each of these signatures:
  - The cosign claims were validated
  - The signatures were verified against the specified public key
  - Any certificates were verified against the Fulcio roots.
{"critical":{"identity":{"docker-reference":"gcr.io/some-image-registry/<image-prefix>-app-helloworld:mnf"},"image":{"docker-manifest-digest":"sha256:79a0fe5ada7b1fcbdaasdasdsadsadasd2b4d2b63cd58ac506265f903cd19d"},"type":"cosign container image signature"},"optional":null}
```

To check the downloaded manifest, run:

```shell
$ tar xzf tmp/artifact.tar.gz
$ tree /tmp
compressing-tar-gz202395025
│   └── manifest.yaml
```

## Verifying provenance generated by ArgoCD Interlace

To verify the signature and provenace of manifest, install [k8s-manifest-sigstore](https://github.com/sigstore/k8s-manifest-sigstore) cli and run:

```
kubectl sigstore verify-resource -n helloworld-ns\
      -i gcr.io/some-image-registry/<image-prefix>-app-helloworld:mnf\
      -k ./cosign.pub --provenance
```      

Successfull verification will show the following output:
```
[SUMMARY]
TOTAL   VALID   INVALID
3       3       0

[MANIFESTS]
NAME                                                              SIGNED   SIGNER
gcr.io/some-image-registry/<image-prefix>-app-helloworld:<sometag>   true     N/A

[RESOURCES]
KIND         NAME             VALID   ERROR   AGE
ConfigMap    the-map          true            22h
Service      the-service      true            22h
Deployment   the-deployment   true            22h

[RESOURCES - PODS/CONTAINERS]
POD                              CONTAINER       IMAGE ID
the-deployment-74f98c845-cg597   the-container   docker.io/monopole/hello@sha256:c8273383d314bfb945f5a879559599990f055da92ee078bf0f960e006c8ebe8b
the-deployment-74f98c845-qrzg2   the-container   docker.io/monopole/hello@sha256:c8273383d314bfb945f5a879559599990f055da92ee078bf0f960e006c8ebe8b
the-deployment-74f98c845-vb8wh   the-container   docker.io/monopole/hello@sha256:c8273383d314bfb945f5a879559599990f055da92ee078bf0f960e006c8ebe8b 

[PROVENANCES - ATTESTATIONS]
ARTIFACT                 gcr.io/some-image-registry/<image-prefix>-app-helloworld:mnf
MATERIALS 1   URI        https://github.com/kubernetes-sigs/kustomize
              COMMIT     0bb9beb2e79ece9805aa62620c1bde309e644f49
              PATH       examples/helloWorld/
              REVISION   master
To get this attestation: curl -s "https://rekor.sigstore.dev/api/v1/log/entries/?logIndex=686609"

```
